@@ -1,14 +1,12 @@
 from .base import Tool, ToolRegistry
 from .file_ops import FileOperationTool
-from .search import SearchTool
 from .shell import ShellTool
-from .webpage import WebpageTool
+from .generator import ToolGeneratorTool
 
 __all__ = [
     'Tool',
     'ToolRegistry',
     'FileOperationTool',
-    'SearchTool',
     'ShellTool',
-    'WebpageTool',
+    'ToolGeneratorTool',
 ] 
