@@ -1,9 +1,18 @@
-from typing import Dict, Any
+from typing import Dict, Any, Protocol, Optional
 import os
 import tempfile
-import shlex
 from pathlib import Path
-from ..utils import PrettyOutput, OutputType
+from enum import Enum
+
+class OutputType(Enum):
+    INFO = "info"
+    ERROR = "error"
+
+class OutputHandler(Protocol):
+    def print(self, text: str, output_type: OutputType) -> None: ...
+
+class ModelHandler(Protocol):
+    def chat(self, message: str) -> str: ...
 
 class ShellTool:
     name = "execute_shell"
@@ -14,15 +23,22 @@ class ShellTool:
         "properties": {
             "command": {
                 "type": "string",
-                "description": "Shell command to execute (filter output when possible)"
+                "description": "Shell command to execute"
             }
         },
         "required": ["command"]
     }
 
+    def __init__(self, **kwargs):
+        self.output = kwargs.get('output_handler')
+        
+    def _print(self, text: str, output_type: OutputType = OutputType.INFO):
+        """输出信息"""
+        if self.output:
+            self.output.print(text, output_type)
+
     def _escape_command(self, cmd: str) -> str:
         """转义命令中的特殊字符"""
-        # 将命令中的单引号替换为'"'"'
         return cmd.replace("'", "'\"'\"'")
 
     def execute(self, args: Dict) -> Dict[str, Any]:
@@ -39,7 +55,7 @@ class ShellTool:
             # 修改命令以使用script
             tee_command = f"script -q -c '{escaped_command}' {output_file}"
             
-            PrettyOutput.print(f"执行命令: {command}", OutputType.INFO)
+            self._print(f"执行命令: {command}")
             
             # 执行命令
             return_code = os.system(tee_command)
@@ -70,6 +86,7 @@ class ShellTool:
             # 确保清理临时文件
             if 'output_file' in locals():
                 Path(output_file).unlink(missing_ok=True)
+            self._print(str(e), OutputType.ERROR)
             return {
                 "success": False,
                 "error": str(e)
